@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "20.0.1";
+        "21.0.9";
 
     private static final String java_version_date =
-        "2023-04-18";
+        "2025-10-21";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,28 +49,28 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "20.0.1+9";
+        "21.0.9+10-LTS";
 
     private static final String VERSION_NUMBER =
-        "20.0.1";
+        "21.0.9";
 
     private static final String VERSION_SPECIFICATION =
-        "20";
+        "21";
 
     private static final String VERSION_BUILD =
-        "9";
+        "10";
 
     private static final String VERSION_PRE =
         "";
 
     private static final String VERSION_OPT =
-        "";
+        "LTS";
 
     private static final boolean isLTS =
-        "".startsWith("LTS");
+        "LTS".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "64.0";
+        "65.0";
 
     private static final String VENDOR =
         "Eclipse Adoptium";
@@ -83,7 +83,7 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static String VENDOR_VERSION =
-        "Temurin-20.0.1+9";
+        "Temurin-21.0.9+10";
 
     private static String VENDOR_URL_BUG =
         "https://github.com/adoptium/adoptium-support/issues";
